From: Andrew Cagney <ac131313@ges.redhat.com>
To: Andrew Cagney <ac131313@ges.redhat.com>
Cc: gdb-patches@sources.redhat.com
Subject: Re: [patch/rfc] Don't include vector registers in ``info registers''
Date: Thu, 08 Aug 2002 17:07:00 -0000 [thread overview]
Message-ID: <3D5307C9.2010003@ges.redhat.com> (raw)
In-Reply-To: <3D53041D.90609@ges.redhat.com>
[-- Attachment #1: Type: text/plain, Size: 940 bytes --]
[With patch]
> Hello,
>
> The attached patch modifies the generic ``info registsters'' command so that it precludes vector registers (in addition to floating-point registers). The online doco indicates:
>
> (gdb) help info registers
> List of integer registers and their contents, for selected stack frame.
> Register name as argument means describe only that register.
> (gdb) help info all-registers
> List of all registers and their contents, for selected stack frame.
> Register name as argument means describe only that register.
>
> I think the change makes the behavour a better match for both the documentation and what I think is the intent of the command. Print a minimal set of registers.
>
> It will eventually affect the i386 -- I've a patch to change the type of xmm [and mmx] registers to true vectors. When that is in, ``info registers'' will stop displaying the xmm registers.
>
> Thoughts?
>
> enjoy,
> Andrew
[-- Attachment #2: diffs --]
[-- Type: text/plain, Size: 1747 bytes --]
2002-08-08 Andrew Cagney <cagney@redhat.com>
* infcmd.c (do_registers_info): Rename parameter ``fpregs'' to
``print_all''. Only print vector registers when ``print_all''.
Index: infcmd.c
===================================================================
RCS file: /cvs/src/src/gdb/infcmd.c,v
retrieving revision 1.49
diff -u -r1.49 infcmd.c
--- infcmd.c 3 Jul 2002 20:36:54 -0000 1.49
+++ infcmd.c 8 Aug 2002 21:14:22 -0000
@@ -1549,9 +1549,9 @@
#ifdef REGISTER_NAMES
char *gdb_register_names[] = REGISTER_NAMES;
#endif
-/* Print out the machine register regnum. If regnum is -1,
- print all registers (fpregs == 1) or all non-float registers
- (fpregs == 0).
+/* Print out the machine register regnum. If regnum is -1, print all
+ registers (all == 1) or all non-float and non-vector registers (all
+ == 0).
For most machines, having all_registers_info() print the
register(s) one per line is good enough. If a different format
@@ -1561,7 +1561,7 @@
to provide that format. */
void
-do_registers_info (int regnum, int fpregs)
+do_registers_info (int regnum, int print_all)
{
register int i;
int numregs = NUM_REGS + NUM_PSEUDO_REGS;
@@ -1570,11 +1570,17 @@
for (i = 0; i < numregs; i++)
{
- /* Decide between printing all regs, nonfloat regs, or specific reg. */
+ /* Decide between printing all regs, non-float / vector regs, or
+ specific reg. */
if (regnum == -1)
{
- if (TYPE_CODE (REGISTER_VIRTUAL_TYPE (i)) == TYPE_CODE_FLT && !fpregs)
- continue;
+ if (!print_all)
+ {
+ if (TYPE_CODE (REGISTER_VIRTUAL_TYPE (i)) == TYPE_CODE_FLT)
+ continue;
+ if (TYPE_VECTOR (REGISTER_VIRTUAL_TYPE (i)))
+ continue;
+ }
}
else
{
next prev parent reply other threads:[~2002-08-09 0:07 UTC|newest]
Thread overview: 11+ messages / expand[flat|nested] mbox.gz Atom feed top
2002-08-08 16:52 Andrew Cagney
2002-08-08 17:07 ` Andrew Cagney [this message]
2002-08-08 19:07 ` Elena Zannoni
2002-08-08 19:24 ` Andrew Cagney
2002-08-13 14:45 ` Andrew Cagney
2002-08-09 11:39 ` Andrew Cagney
2002-08-15 17:12 ` Andrew Cagney
2002-08-08 18:33 ` Daniel Jacobowitz
2002-08-08 18:45 ` Michael Snyder
2002-08-08 19:35 ` Andrew Cagney
2002-08-08 18:50 ` Michael Snyder
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=3D5307C9.2010003@ges.redhat.com \
--to=ac131313@ges.redhat.com \
--cc=gdb-patches@sources.redhat.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox